drop1 calculates revised combined uncertainty for single variable deletions from
an object of class 'uncert'.
"drop1"(object, scope, simplify = TRUE,
which=c("% Change", "var", "u", "var.change", "u.change"), ...)
"drop1"(object, scope, simplify = TRUE,
which=c("% Change", "var", "u", "var.change", "u.change"), ...)
#Print and plot methods
"print"(x, ..., digits=2)
"plot"(x, ...,
which=c("% Change", "var", "u", "var.change", "u.change"))scope.simplify=TRUE, the return value is simplified to
a named vector. If FALSE, all forms available (see which) are
returned in a data frame.simplify=TRUE.
Possible values are:
"var"
"u"
"var.change"
"u.change"
"% Change"
drop1.uncert.
digits argument
of format.
simplify=FALSE, an object of class drop1.uncert, consisting of a
data frame with row names corresponding to row.names(object$budget), columns
corresponding to all possible values of which in the order "var", "u", "var.change",
"u.change", "% Change", and an attribute expr containing a copy of the expr
value of the 'uncert' object to which drop1.uncert is applied.If simplify=TRUE, the column of the above data frame corresponding to which
is returned as a vector with names row.names(object$budget).
drop1, drop1.uncert perfoms single variable deletions from
the uncertainty budget in object, calculates the resulting uncertainty and returns the
results in the form requested by simplify and which.Single variable deletion of a variable $x[i]$ is equivalent to setting the uncertainty
$u(x[i])$ to zero. Note that this also sets covariance terms involving $x[i]$
to zero. drop1.uncert does not support the deletion of single terms such as $cov(i, j)$.
In the case of uncertMC objects, drop1 currently requires object$MC$x to be
present (i.e. uncertMC called with keep.x=TRUE). The uncertMC
method does not support correlation.
For which="var.change", which="u.change" and which="% Change" the
change on dropping a variable is negative if the uncertainty reduces on removing the variable.
The print method simply prints the output with a header formed from the expr attribute
and with '%' appended to the "% Change" column.
The plot method produces a barplot of the chosen data column. Arguments in ... are passed to
barplot. If not already present in ... a default main title and ylab are used. The expr
attribute is shown as marginal text if not NA.
uncert, uncert-class, format for digits,
barplot for available plot parameters.
#Continuing the example from plot.uncert:
require(graphics)
d1<-drop1(u.form.c, simplify=FALSE)
d1
plot(d1)
drop1(u.form.c) #% change only
Run the code above in your browser using DataLab