Usage
mandel.kh(x, g = NULL, m = NULL, na.rm = T, rowname = NULL,
type = c("h", "k"), method=c("classical", "robust"), n = NA, ...)
## S3 method for class 'default':
mandel.kh(x, g = NULL, m = NULL, na.rm = T, rowname = NULL,
type = c("h", "k"), method=c("classical", "robust"), n = NA, ...)
## S3 method for class 'data.frame':
mandel.kh(x, g = NULL, m = NULL, na.rm = T, rowname = NULL,
type = c("h", "k"), method=c("classical", "robust"), n = NA, ...)
## S3 method for class 'matrix':
mandel.kh(x, g = NULL, m = NULL, na.rm = T, rowname = NULL,
type = c("h", "k"), method=c("classical", "robust"), n = NA, ...)
## S3 method for class 'array':
mandel.kh(x, g = NULL, m = NULL, na.rm = T, rowname = NULL,
type = c("h", "k"), method=c("classical", "robust"), n = NA, ...)
## S3 method for class 'ilab':
mandel.kh(x, g = NULL, m = NULL, na.rm = T, rowname = NULL,
type = c("h", "k"), method=c("classical", "robust"), n = NA, ...)Arguments
x
An R object (see Details below), which contains replicate observations or,
if g is absent, means or standard deviations.
g
A primary grouping factor, usually corresponding to Laboratory in an
inter-laboratory study. If not present, x is taken as
a set of means or standard deviations (depending on whether
type is "h" or <
m
A secondary grouping factor, usually corresponding to test item
or measured quantity. m is ignored if x has
more than one column.
na.rm
A logical value indicating whether 'NA' values should be
stripped before the computation proceeds. Passed to functions
such as mean and sd.
rowname
A single character label for the primary grouping factor
(e.g. "Lab", "Organisation").
type
Character denoting the statistic to be calculated; may be "h" or "k".
method
Character scalar giving the calculation method. "classical" gives the
traditional calculation; "robust" gives a robust variant (see Details).
n
scalar number of observations per group. Required only if x consists of
calculated standard deviations.
...
Additional parameters passed to hubers when method="robust"
and type="h".