uncert calls.
"print"(x, digits=NULL, right=FALSE, ..., simplify=TRUE)
"summary"(object, ..., simplify=TRUE)format for distribution parameter list and to print.data.frame
for output.print.data.frame.print.data.frameTRUE, only the call, evaluation method, budget, value y
and combined uncertainty (u.y) are printed.print and summary methods invisibly return the original object.
simplify=TRUE; this displays a shortened listing. Columns in $budget are
suppressed if all NA (typically df when not specified).summary.uncert simply calls print.uncert.An object of class "uncert" contains:
x (if supplied; otherwise a vector of NA's).
u)
u
c or (for the formula, function
and expression methods) as calculated.
u and c. These are the contributions to the
combined uncertainty for uncorrelated quantities.
u.
The list contains either root nams of distribution functions (e.g "norm" or
function definitions.
u.
cov.xy
deriv;
an expression which evaluates to the value with attributes corresponding to the derivatives
(that is, an expression which can be evaluated to give the value and sensitivity coefficients)
uncert, especially for calculation methods;
plot.uncert, uncertMC-class,
print.data.frame, format.
expr <- expression(a+b*2+c*3+d/2)
x <- list(a=1, b=3, c=2, d=11)
u <- lapply(x, function(x) x/10)
u.expr<-uncert(expr, x, u, method="NUM")
print(u.expr)
Run the code above in your browser using DataLab