uncertMC calls and by uncertainty with method="MC".summary.uncertMC is currently an alias for print.uncertMC.
"print"(x, digits=NULL, right=FALSE, ..., simplify=TRUE, minimise=FALSE)
"summary"(object, digits=NULL, right=FALSE, ..., simplify=TRUE, minimise=FALSE)"uncertMC"format for distribution parameter list and to print.data.frame
for output.print.data.frame.print.data.frameTRUE, only the call, evaluation method, budget, value y
and combined uncertainty (u.y) are printed.TRUE, the header, call, expr and evaluation method
are suppressed; this is the mode used when printing an uncertMC object as part of an
uncert object.print and summary methods invisibly return the original object.
simplify=TRUE; this displays a shortened listing. Columns in $data are
suppressed if all NA.
uncertMC.
x.
u)
u
uncertMC
for how this is done).
u.
The list contains either root nams of distribution functions (e.g "norm" or
function definitions.
u.
$budget$x
(typically addditional constants passed to function or expression methods)
uncertMC objects only
"pearson" is currently supported (because "kendall" and "spearman"
take a very long time to compute)
cov.xy
.Random.seed when uncertMC was called.
B Monte Carlo replicates of the standard uncertainty
calculated as sd(y).
uncertMC is called with keep.x=TRUE, a data frame
whose columns are the Monte Carlo replicates of the variables in x.
uncert, uncertMC, uncert-class,
print.data.frame, format.
set.seed(13*17)
expr <- expression(a+b*2+c*3+d/2)
x <- list(a=1, b=3, c=2, d=11)
u <- lapply(x, function(x) x/10)
u.expr<-uncertMC(expr, x, u, distrib=rep("norm", 4), method="MC")
print(u.expr)
Run the code above in your browser using DataLab