w.s is an alias for welch.satterthwaite.
w.s(ui, df, ci = rep(1, length(ui)), uc=sqrt(sum((ci*ui)^2)))
welch.satterthwaite(ui, df, ci = rep(1, length(ui)), uc=sqrt(sum((ci*ui)^2)))uc.
uc is the
uncertainty in a measurement result $y$, where $y=f(x_1, x_2, \dots)$, ci are
the partial derivatives $dy/dx[i]$ and ui is the standard uncertainty associated with xi.The implementation assumes that the combined uncertainty uc is equal to
sqrt(sum((ci*ui)^2). An independent estimate of uc can be provided.
The ci are 'sensitivity coefficients'; the default is 1, so that the ui
can be given either as standard uncertainties in the values of influence quantities $x_i$,
together with the associated ci, or as contributions ci*ui to the uncertainty in $y$.
Correlation is not supported, because the Welch-Satterthwaite equation is only valid for independent variances.
Satterthwaite, F. E. (1946), An Approximate Distribution of Estimates of Variance Components., Biometrics Bulletin 2, 110-114, doi:10.2307/3002019
Welch, B. L. (1947), The generalization of "Student's" problem when several different population variances are involved., Biometrika 34 28-35
u <- c(0.1, 0.3, 0.2, 1.1)
ci <- c(1.0, 2.0, 3.0, 0.5)
degfree <- c(Inf,6,8,3)
w.s(ui=u,df=degfree, ci=ci)
Run the code above in your browser using DataLab